@@ -60,12 +60,12 @@ def make_option_parser():
     parser.add_option("-e", "--environments", 
                       dest="environments", type="string", 
                       action='append',
-                      default=["browser"],
+                      default=[],
                       help="target environments (e.g. browser or node)")
     parser.add_option("-t", "--transports", 
                       dest="transports", type="string", 
                       action="append",
-                      default=["csp"],
+                      default=[],
                       help="target transport (e.g. csp or tcp)")
     parser.add_option("--v", 
                       action="store_const", const=logging.INFO, dest="verbose")
@@ -97,7 +97,7 @@ def main(argv=None):
     
     global minify
     if not options.minify:
-        minify = lambda x: x
+        minify = lambda x, path=None: x
     elif options.google:
         minify = google_jar_minify
     elif options.google_rest:
@@ -136,7 +136,7 @@ def main(argv=None):
     output += options.initialImport;
     if options.minify:
         log.info("Minifying")
-        output = minify(output)
+        output = minify(output, path='output')
     else:
         log.info("Skipping minify")
     print "Writing output %s" % OUTPUT
@@ -152,9 +152,11 @@ def main(argv=None):
         soup.head.insert(0, tag1)
         output = soup.prettify()
         
-    f = fileopen(OUTPUT, 'w')
-    f.write(output)
-    f.close()
+    if OUTPUT:
+        f = fileopen(OUTPUT, 'w')
+        f.write(output)
+        f.close()
+    return output
 
 def load_package_configuration(INPUT, options):
     """ load the configuration options in the specified pkg
@@ -271,7 +273,7 @@ def compile_source(target, options, extras=[]):
         log.debug('full_path: %s', full_path)
         if full_path in checked:
             continue
-        log.debug('checking dependancy %s', full_path)
+        log.debug('getting dependancies for %s', full_path)
         target = path_for_module(full_path, prefix=options.jsio)
         src = remove_comments(get_source(target))
         depends = map(lambda x: (x, full_path), extract_dependencies(src))
@@ -280,22 +282,21 @@ def compile_source(target, options, extras=[]):
             checked.append(full_path)
         
     sources = {}
-    sources[target_module] = dict(src=minify(target_source),
+    sources[target_module] = dict(src=minify(target_source,path=target_module_path),
                                   filePath=target_module_path)
     log.debug('checked is %s', checked)
     for full_path in checked:
         if full_path in (target_module, 'jsio', # 'jsio.env',
                          'log', 'Class', 'bind'):
             continue
-        log.info("Loading dependancy %s", full_path)
         filename = path_for_module(full_path, prefix=options.jsio)
-        log.info("filename: %s", filename)
+        log.info("Loading dependancy %s from %s", full_path, filename)
         src = get_source(filename)
             
         virtual_filename = path_for_module(full_path, prefix='jsio')
         log.debug(virtual_filename)
-            
-        sources[full_path] = {'src': minify(src), 'filePath': virtual_filename, }
+        
+        sources[full_path] = {'src': minify(src,path=virtual_filename), 'filePath': virtual_filename, }
         
     out = ',\n'.join([ repr(str(key)) + ": " + json.dumps(val)
                        for (key, val) in sources.items() ])
@@ -344,8 +345,8 @@ def extract_dependencies(src):
     for item in re2.finditer(src):
         for listItem in re3.finditer(item.groups()[0]):
             dependencies.append(listItem.groups()[0])
-#    if dependencies:
-#        print 'returning', dependencies
+    
+    log.debug('deps: ' + ', '.join(dependencies))
     return dependencies
     
 def remove_comments(src):
@@ -515,30 +516,32 @@ def unmonkeypatch(BeautifulSoupClass=None):
     delattr(BeautifulSoupClass, 'findSelect')
 
 
-def google_jar_minify(src):
-    import commands, os
+def google_jar_minify(src, path=None):
+    import os, subprocess
+
     compiler = os.path.join(os.path.dirname(__file__), 'compiler.jar')
     if not os.path.exists(compiler):
         compiler = 'compiler.jar'
         if not os.path.exists(compiler):
             log.critical('ERROR: could not find google closure\'s compiler.jar for -g option')
             sys.exit(1)
-    f = open('.pyjsiocompile.temp.js', 'w')
-    f.write(src)
-    f.close()
-    command = 'java -jar %s --js .pyjsiocompile.temp.js --js_output_file .pyjsiocompile.temp2.js --compilation_level SIMPLE_OPTIMIZATIONS' % (compiler,)
-    log.debug(command)
-    code, out = commands.getstatusoutput(command)
-    log.debug(out)
-    if code:
-        data = src
-    else:
-        data = open('.pyjsiocompile.temp2.js').read()
-    os.remove('.pyjsiocompile.temp.js')
-    os.remove('.pyjsiocompile.temp2.js')
-    return data
+    compilation_level = 'SIMPLE_OPTIMIZATIONS' # 'ADVANCED_OPTIMIZATIONS', 'WHITESPACE_ONLY'
+    warning_level = 'DEFAULT' # 'QUIET', 'VERBOSE'
 
-def google_minify(src):
+    log.info('closure compiler minifying %s', path)
+    command = ['java', '-jar', compiler, '--compilation_level', compilation_level, '--warning_level', warning_level]
+    handle = subprocess.Popen(command, stdin=subprocess.PIPE, stdout=subprocess.PIPE, stderr=subprocess.PIPE)
+    stdout, stderr = handle.communicate(src)
+    if handle.returncode:
+        log.error('Failed compiling %s', path)
+	log.error(stderr)
+        sys.exit(handle.returncode)
+    elif stderr:
+	log.warn('compiler warnings for %s', path)
+        log.warn(stderr)
+    return stdout
+
+def google_minify(src, path=None):
     print '*Google minify'
     # Code from http://code.google.com/closure/compiler/docs/api-tutorial1.html
     import httplib, urllib, sys
